# NOMAD-CAMELS Driver for Keithley Current Source 6221

This is a basic driver designed to be able to control the Keithley current
source 6221 in NOMAD-CAMELS. This integration does not fully cover the device's
capabilities, but it can be used as a base to develop a more feature-rich driver
for this device.

## Useful Links

- [NOMAD-CAMELS Documentation](https://fau-lap.github.io/NOMAD-CAMELS/index.html)
- [NOMAD-CAMELS: create new instrument drivers documentation](https://fau-lap.github.io/NOMAD-CAMELS/doc/programmers_guide/instrument_drivers.html)
- [Keithley current source 6221 manual](https://download.tek.com/manual/622x-901-01%20(C%20-%20Oct%202008)(Ref).pdf)
